@@ -211,7 +211,7 @@ var app = new Vue({
             rows: [],
             columns: [],
             total: 0,
-            currentPage: ( current.page ? parseInt( current.page ) : 0 ),
+            currentPage: ( current.page ? parseInt( current.page ) : 1 ),
             perPage: 25,
             fetching: false,
             error: {},
@@ -347,7 +347,7 @@ var app = new Vue({
                 self = this,
                 paging = {
                     limit: this.perPage,
-                    offset: this.perPage * this.currentPage
+                    offset: this.perPage * ( this.currentPage - 1 )
                 };
             this.fetching = true;
             delete this.error.fetchPage;
@@ -571,12 +571,29 @@ var app = new Vue({
     computed: {
         totalPages: function () {
             var mod = this.total % this.perPage,
-                pages = this.total / this.perPage;
-            if ( mod == 0 ) {
+                pages = this.total / this.perPage,
+                totalPages = mod == 0 ? pages : Math.floor( pages ) + 1;
+            return totalPages;
+        },
+
+        pagerPages: function () {
+            var totalPages = this.totalPages,
+                currentPage = this.currentPage,
+                pages = [];
+            if ( totalPages < 10 ) {
+                for ( var i = 1; i <= totalPages; i++ ) {
+                    pages.push( i );
+                }
                 return pages;
             }
-            return Math.floor( pages ) + 1;
+            var minPage = currentPage > 4 ? currentPage - 4 : 1,
+                maxPage = minPage + 9 < totalPages ? minPage + 9 : totalPages;
+            for ( var i = minPage; i < maxPage; i++ ) {
+                pages.push( i );
+            }
+            return pages;
         },
+
         operations: function () {
             return this.collections[ this.currentCollection ] ? this.collections[ this.currentCollection ].operations : {};
         },
@@ -587,7 +604,7 @@ var app = new Vue({
     watch: {
         currentCollection: function () {
             this.data = [];
-            this.currentPage = 0;
+            this.currentPage = 1;
             this.openedRow = null;
             this.addingItem = false;
             this.fetching = false;
