@@ -1,5 +1,5 @@
 package Yancy::Plugin::Auth::Basic;
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 # ABSTRACT: A simple auth module for a site
 
 #pod =encoding utf8
@@ -182,6 +182,20 @@ our $VERSION = '0.017';
 #pod
 #pod This plugin adds the following Mojolicious helpers:
 #pod
+#pod =head2 yancy.auth.route
+#pod
+#pod The L<route object|Mojolicious::Routes::Route> that requires
+#pod authentication.  Add your own routes as children of this route to
+#pod require authentication for your own routes.
+#pod
+#pod     my $auth_route = $app->yancy->auth->route;
+#pod     $auth_route->get( '/', sub {
+#pod         my ( $c ) = @_;
+#pod         return $c->render(
+#pod             data => 'You are authorized to view this page',
+#pod         );
+#pod     } );
+#pod
 #pod =head2 yancy.auth.current_user
 #pod
 #pod Get/set the currently logged-in user. Returns C<undef> if no user is
@@ -250,8 +264,14 @@ sub register {
     } );
     push @{ $app->yancy->config->{collections}{$coll}{properties}{$password_field}{'x-filter'} }, 'auth.digest';
 
-    # Add authentication check
+    # Add login pages
     my $route = $config->{route} || $app->yancy->route;
+    push @{ $app->renderer->classes }, __PACKAGE__;
+    $route->get( '/login', \&_get_login, 'yancy.login_form' );
+    $route->post( '/login', \&_post_login, 'yancy.check_login' );
+    $route->get( '/logout', \&_get_logout, 'yancy.logout' );
+
+    # Add authentication check
     my $auth_route = $route->under( sub {
         my ( $c ) = @_;
         # Check auth
@@ -273,8 +293,17 @@ sub register {
     my @routes = @{ $route->children }; # Loop over copy while we modify original
     for my $r ( @routes ) {
         next if $r eq $auth_route; # Can't reparent ourselves or route disappears
+
+        # Don't add auth to unauthed routes. We need to add the plugin's
+        # routes first so that they are picked up before the `under` we
+        # created, but now we're going back to add auth to all
+        # previously-created routes, so we need to skip the ones that
+        # must be visited by unauthed users.
+        next if grep { $r->name eq $_ } qw( yancy.login_form yancy.check_login yancy.logout );
+
         $auth_route->add_child( $r );
     }
+    $app->helper( 'yancy.auth.route' => sub { $auth_route } );
 
     # Add auth helpers
     $app->helper( 'yancy.auth.get_user' => sub {
@@ -302,11 +331,6 @@ sub register {
         delete $c->session->{ username };
     } );
 
-    # Add login pages
-    push @{ $app->renderer->classes }, __PACKAGE__;
-    $route->get( '/login' )->to( cb => \&_get_login )->name( 'yancy.login_form' );
-    $route->post( '/login' )->to( cb => \&_post_login )->name( 'yancy.check_login' );
-    $route->get( '/logout' )->to( cb => \&_get_logout )->name( 'yancy.logout' );
 }
 
 sub _get_login {
@@ -345,7 +369,7 @@ Yancy::Plugin::Auth::Basic - A simple auth module for a site
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 DESCRIPTION
 
@@ -526,6 +550,20 @@ store the Base64-encoded result instead.
 
 This plugin adds the following Mojolicious helpers:
 
+=head2 yancy.auth.route
+
+The L<route object|Mojolicious::Routes::Route> that requires
+authentication.  Add your own routes as children of this route to
+require authentication for your own routes.
+
+    my $auth_route = $app->yancy->auth->route;
+    $auth_route->get( '/', sub {
+        my ( $c ) = @_;
+        return $c->render(
+            data => 'You are authorized to view this page',
+        );
+    } );
+
 =head2 yancy.auth.current_user
 
 Get/set the currently logged-in user. Returns C<undef> if no user is
